<template>
  <div class="app-container">
    <div class="search_form">
      <div>
        <span class="search_title">供应商名称:</span>
        <el-input
          v-model="searchForm.supplierNameOrContractNo"
          style="width: 240px"
          placeholder="输入供应商名称"
          @change="handleQuery"
          clearable
          :prefix-icon="Search"
        />
        <el-button type="primary" @click="handleQuery" style="margin-left: 10px"
          >搜索</el-button
        >
      </div>
      <div></div>
    </div>
    <el-row>
      <el-col :span="14">
        <div class="table_list">
          <el-table
            ref="multipleTable"
            v-loading="tableLoading"
            :data="tableData"
            :header-cell-style="{ background: '#F0F1F5', color: '#333333' }"
            height="calc(100vh - 18.5em)"
            :highlight-current-row="true"
            style="width: 100%"
            tooltip-effect="dark"
            @row-click="rowClick"
            :show-summary="isShowSummary"
            class="lims-table"
          >
            <el-table-column
              align="center"
              label="序号"
              type="index"
              width="60"
            />
            <el-table-column
              v-for="(item, index) in tableColumn"
              :key="index"
              :column-key="item.columnKey"
              :filter-method="item.filterHandler"
              :filter-multiple="item.filterMultiple"
              :filtered-value="item.filteredValue"
              :filters="item.filters"
              :fixed="item.fixed"
              :label="item.label"
              :prop="item.prop"
              show-overflow-tooltip
              :align="item.align"
              :sortable="!!item.sortable"
              :type="item.type"
              :width="item.width"
            >
            </el-table-column>
          </el-table>
        </div>
      </el-col>
      <el-col :span="10">
        <div class="table_list">
          <PIMTable
            :column="tableColumnSon"
            :tableData="tableDataSon"
            :page="pageSon"
            :isSelection="false"
            :tableLoading="tableLoadingSon"
            :isShowSummary="isShowSummarySon"
          ></PIMTable>
        </div>
      </el-col>
      <div class="el-pagination">
        <pagination
          v-show="total > 0"
          @pagination="paginationSearch"
          :total="total"
          :layout="page.layout"
          :page="page.current"
          :limit="page.size"
        />
      </div>
    </el-row>
  </div>
</template>

<script setup>
import { ref, toRefs } from "vue";
import { Search } from "@element-plus/icons-vue";
import { paymentLedgerList } from "@/api/procurementManagement/paymentLedger.js";

const tableColumn = ref([
  {
    label: "供应商名称",
    prop: "supplierName",
  },
  {
    label: "发票金额(元)",
    prop: "invoiceAmount",
  },
  {
    label: "付款金额(元)",
    prop: "paymentAmount",
  },
  {
    label: "应付金额(元)",
    prop: "payableAmount",
  },
]);
const tableData = ref([]);
const tableLoading = ref(false);
const data = reactive({
  searchForm: {
    supplierNameOrContractNo: "",
  },
});
const page = reactive({
  current: 1,
  size: 10,
});
const total = ref(0);
const isShowSummary = ref(true);
const { searchForm } = toRefs(data);
const rowClick = (row) => {
  tableDataSon.value = Array.isArray(row.details) ? row.details : [];
};
// 子模块
const tableColumnSon = ref([
  {
    label: "付款日期",
    prop: "paymentDate",
  },
  {
    label: "开票数",
    prop: "voteCount",
  },
  {
    label: "付款金额(元)",
    prop: "paymentAmount",
  },
  {
    label: "应付金额(元)",
    prop: "payableAmount",
  },
]);
const tableDataSon = ref([]);
const tableLoadingSon = ref(false);
const isShowSummarySon = ref(true);
const detailPageNum = ref(1);
const detailPageSize = ref(10);

/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1;
  getList();
};
const paginationSearch = ({ current, limit }) => {
  page.current = current;
  page.size = limit;
  tableDataSon.value = [];
  getList();
};
const getList = () => {
  tableLoading.value = false;
  paymentLedgerList({
    ...searchForm.value,
    ...page,
    detailPageNum: detailPageNum.value, // 新增
    detailPageSize: detailPageSize.value, // 新增
  }).then((res) => {
    let result = res.data;
    tableLoading.value = false;
    tableData.value = result.records || [];
    total.value = result.total || 0;
  });
};

getList();
</script>

<style scoped lang="scss">
.el-row {
  .el-col-14 {
    .table_list {
      padding-right: 0px;
    }
  }
  .el-col-10 {
    .table_list {
      padding-left: 0px;
    }
  }
}
.el-pagination {
  width: 100%;
  height: 55px;
  display: flex;
  justify-content: flex-end;
  float: right;
  flex-direction: row;
  align-items: center;
  background: #fff;
  margin: -20px 0 0 0;
  padding: 0 20px;
}
.pagination-container {
  margin-top: 0;
}
.table_list {
  height: calc(100vh - 13.5em);
  overflow: auto;
}
</style>
